"""
Update notification functionality for RedXSecureUpdater
"""
import logging
from pathlib import Path

class UpdateNotifier:
    def __init__(self):
        self.logger = logging.getLogger(__name__)

    def show_update_progress(self, status, progress=0):
        """Show update progress using console notifications"""
        self._console_notification(status, progress)

    def show_update_complete(self):
        """Show update completion notification"""
        self._console_notification("Update completed successfully!", 100)

    def show_update_failed(self):
        """Show update failure notification"""
        self._console_notification("Update failed. Rolling back changes...", 0)

    def _console_notification(self, status, progress):
        """Console notification"""
        self.logger.info("=" * 50)
        self.logger.info("RedXSecureUpdater Status")
        self.logger.info(f"Status: {status}")
        self.logger.info(f"Progress: {'=' * int(progress/2)}> {progress}%")
        self.logger.info("=" * 50)